@@ -11,7 +11,7 @@ LOGGER_NAME = "RPCClient"
 
 class RPCClient(object):
     def __init__(self,
-                 ip: str = "127.0.0.1",
+                 ip: str = "localhost",
                  port: int = 9090,
                  cb_connected: Callable[[], None] = None,
                  cb_disconnected: Callable[[], None] = None,
@@ -43,7 +43,11 @@ class RPCClient(object):
 
     @property
     def remote_address(self):
-        return f"{self.__ws.host}:{self.__ws.port}"
+        return f"{self.__ws.remote_address[0]}:{self.__ws.remote_address[1]}"
+
+    @property
+    def local_address(self):
+        return f"{self.__ws.local_address[0]}:{self.__ws.local_address[1]}"
 
     def __pack_rpc(self,
                    rpc_id: int,
@@ -106,10 +110,10 @@ class RPCClient(object):
                     # 阻塞获取，不担心性能问题
                     ws_data = await self.__ws.recv()
                     loggers.get(LOGGER_NAME).debug(
-                        f"C({self.address}) << S({self.remote_address}): \
+                        f"C({self.local_address}) << S({self.remote_address}): \
 {ws_data}")
                 except Exception as e:
-                    # loggers.get(LOGGER_NAME).error(e, exc_info=True)
+                    loggers.get(LOGGER_NAME).error(e, exc_info=True)
                     if self.__cb_disconnected:
                         result = self.__cb_disconnected()
                         if isinstance(result, asyncio.Future):
@@ -146,6 +150,7 @@ class RPCClient(object):
                 except Exception as e:
                     loggers.get(LOGGER_NAME).warning(
                         f"Can not connect dobotlink: {e}")
+                    print(f"RPCClient - connect server error: {e}")
                     await asyncio.sleep(0.5)
 
     async def send(self, method: str, params: dict = {}) -> Any:
@@ -165,7 +170,7 @@ class RPCClient(object):
         }
 
         loggers.get(LOGGER_NAME).debug(
-            f"C({self.address}) >> S({self.remote_address}): {payload}")
+            f"C({self.local_address}) >> S({self.remote_address}): {payload}")
         await self.__ws.send(json.dumps(payload))
 
         if cb_feedback:
@@ -213,5 +218,6 @@ class RPCClient(object):
 
         rpc_packet = self.__pack_rpc(None, data, method)
         loggers.get(LOGGER_NAME).debug(
-            f"C({self.address}) >> S({self.remote_address}): {rpc_packet}")
+            f"C({self.local_address}) >> S({self.remote_address}): {rpc_packet}"
+        )
         await self.__ws.send(json.dumps(rpc_packet))
