@@ -30,7 +30,8 @@ class RPCServer(object):
                  ip="0.0.0.0",
                  port=9091,
                  on_disconnected=None,
-                 on_connected=None):
+                 on_connected=None,
+                 max_size=3):
         if on_disconnected is not None and not callable(on_disconnected):
             raise Exception("on_disconnected should callable")
         if on_connected is not None and not callable(on_connected):
@@ -57,7 +58,8 @@ class RPCServer(object):
         async def init_worker() -> Any:
             nonlocal ip, port
             self.__server = await websockets.serve(self.__on_new_onnection, ip,
-                                                   port)
+                                                   port,
+                                                   max_size=max_size * (2 ** 20))
 
         self.__loop.run_until_complete(init_worker())
 
@@ -124,7 +126,7 @@ class RPCServer(object):
                 loggers.get(LOGGER_NAME).debug(
                     f"S({address}) << C({remote_address}): {message}")
             except Exception as e:
-                # loggers.get(LOGGER_NAME).error(e, exc_info=True)
+                loggers.get(LOGGER_NAME).error(e, exc_info=True)
                 break
 
             try:
